==> jc-1.4.0.tar.gz: polyglot/visit/CodeCleaner__241.h <==
// class polyglot.visit.CodeCleaner$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 76c97a33763fa721 polyglot_visit_CodeCleaner__241
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_polyglot_visit_CodeCleaner__241_H_
#define _JC_polyglot_visit_CodeCleaner__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Set$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_CodeCleaner$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_CodeCleaner__241$sub_refs	_jc_polyglot_visit_CodeCleaner__241$sub_refs;
typedef struct _jc_polyglot_visit_CodeCleaner__241$sub_nonrefs	_jc_polyglot_visit_CodeCleaner__241$sub_nonrefs;
typedef struct _jc_polyglot_visit_CodeCleaner__241$refs	_jc_polyglot_visit_CodeCleaner__241$refs;
typedef struct _jc_polyglot_visit_CodeCleaner__241$nonrefs	_jc_polyglot_visit_CodeCleaner__241$nonrefs;
typedef struct _jc_polyglot_visit_CodeCleaner__241$object	_jc_polyglot_visit_CodeCleaner__241$object;

typedef const struct _jc_polyglot_visit_CodeCleaner__241$vmethods	_jc_polyglot_visit_CodeCleaner__241$vmethods;
typedef const struct _jc_polyglot_visit_CodeCleaner__241$vtable	_jc_polyglot_visit_CodeCleaner__241$vtable;
typedef const struct _jc_polyglot_visit_CodeCleaner__241$vtype	_jc_polyglot_visit_CodeCleaner__241$vtype;

// Constructors
extern void _jc_polyglot_visit_CodeCleaner__241$method$_init$601301af3b30d09a(_jc_env *, struct _jc_polyglot_visit_CodeCleaner__241$object *, struct _jc_polyglot_visit_CodeCleaner$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_polyglot_visit_CodeCleaner__241$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_polyglot_visit_CodeCleaner__241$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_CodeCleaner__241$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_polyglot_visit_CodeCleaner__241$vmethods {
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_polyglot_visit_CodeCleaner__241$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
};

// Vtable
struct _jc_polyglot_visit_CodeCleaner__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_CodeCleaner__241$vmethods	polyglot_visit_CodeCleaner__241;
};

// Vtype
struct _jc_polyglot_visit_CodeCleaner__241$vtype {
	_jc_type			type;
	_jc_polyglot_visit_CodeCleaner__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_CodeCleaner__241$sub_refs {
	struct _jc_object	*val__24result;
	struct _jc_polyglot_visit_CodeCleaner$object	*this__240;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_CodeCleaner__241$refs {
    _jc_polyglot_visit_CodeCleaner__241$sub_refs	polyglot_visit_CodeCleaner__241;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_CodeCleaner__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_CodeCleaner__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_CodeCleaner__241$sub_nonrefs	polyglot_visit_CodeCleaner__241;
};

// Object instance structure
struct _jc_polyglot_visit_CodeCleaner__241$object {
	_jc_polyglot_visit_CodeCleaner__241$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_CodeCleaner__241$vtype	*vtype;
	_jc_polyglot_visit_CodeCleaner__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_CodeCleaner__241$vtype _jc_polyglot_visit_CodeCleaner__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_CodeCleaner__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_CodeCleaner__241$class_object;

#endif	/* _JC_polyglot_visit_CodeCleaner__241_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/CodeCleaner__241.h <==
// class polyglot.visit.CodeCleaner$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 76c97a33763fa721 polyglot_visit_CodeCleaner__241
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_polyglot_visit_CodeCleaner__241_H_
#define _JC_polyglot_visit_CodeCleaner__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Set$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_CodeCleaner$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_CodeCleaner__241$sub_refs	_jc_polyglot_visit_CodeCleaner__241$sub_refs;
typedef struct _jc_polyglot_visit_CodeCleaner__241$sub_nonrefs	_jc_polyglot_visit_CodeCleaner__241$sub_nonrefs;
typedef struct _jc_polyglot_visit_CodeCleaner__241$refs	_jc_polyglot_visit_CodeCleaner__241$refs;
typedef struct _jc_polyglot_visit_CodeCleaner__241$nonrefs	_jc_polyglot_visit_CodeCleaner__241$nonrefs;
typedef struct _jc_polyglot_visit_CodeCleaner__241$object	_jc_polyglot_visit_CodeCleaner__241$object;

typedef const struct _jc_polyglot_visit_CodeCleaner__241$vmethods	_jc_polyglot_visit_CodeCleaner__241$vmethods;
typedef const struct _jc_polyglot_visit_CodeCleaner__241$vtable	_jc_polyglot_visit_CodeCleaner__241$vtable;
typedef const struct _jc_polyglot_visit_CodeCleaner__241$vtype	_jc_polyglot_visit_CodeCleaner__241$vtype;

// Constructors
extern void _jc_polyglot_visit_CodeCleaner__241$method$_init$601301af3b30d09a(_jc_env *, struct _jc_polyglot_visit_CodeCleaner__241$object *, struct _jc_polyglot_visit_CodeCleaner$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_visit_CodeCleaner__241$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_polyglot_visit_CodeCleaner__241$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_CodeCleaner__241$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_polyglot_visit_CodeCleaner__241$vmethods {
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_polyglot_visit_CodeCleaner__241$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_CodeCleaner__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_CodeCleaner__241$vmethods	polyglot_visit_CodeCleaner__241;
};

// Vtype
struct _jc_polyglot_visit_CodeCleaner__241$vtype {
	_jc_type			type;
	_jc_polyglot_visit_CodeCleaner__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_CodeCleaner__241$sub_refs {
	struct _jc_object	*val__24result;
	struct _jc_polyglot_visit_CodeCleaner$object	*this__240;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_CodeCleaner__241$refs {
    _jc_polyglot_visit_CodeCleaner__241$sub_refs	polyglot_visit_CodeCleaner__241;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_CodeCleaner__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_CodeCleaner__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_CodeCleaner__241$sub_nonrefs	polyglot_visit_CodeCleaner__241;
};

// Object instance structure
struct _jc_polyglot_visit_CodeCleaner__241$object {
	_jc_polyglot_visit_CodeCleaner__241$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_CodeCleaner__241$vtype	*vtype;
	_jc_polyglot_visit_CodeCleaner__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_CodeCleaner__241$vtype _jc_polyglot_visit_CodeCleaner__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_CodeCleaner__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_CodeCleaner__241$class_object;

#endif	/* _JC_polyglot_visit_CodeCleaner__241_H_ */
